git bisect — find the commit that introduced a bug via binary search.
Structs
- Bisect
Command - Builder for
git bisect.
Enums
- Bisect
Action - Actions supported by
git bisect.
git bisect — find the commit that introduced a bug via binary search.
git bisect.git bisect.