Module status

Module status 

Available on crate feature parse only.
Parser for git status --porcelain=v1 -z.

Porcelain v1 is stable across git versions. Each entry is two status characters (XY) followed by a space, the path, and a NUL terminator. A rename or copy (signalled in the index column X) adds one more NUL-terminated field: the entry’s path is the new (destination) path and the extra field is the original path.

Structs

StatusEntry
A single parsed entry from git status --porcelain=v1 -z.

Enums

StatusKind
Classification of a status character.

Functions

parse_status
Parse the output of git status --porcelain=v1 -z.